import os
import os.path

from django.core.files.storage import default_storage
from django.core.urlresolvers import reverse
from django.http import HttpResponse, Http404, HttpResponseRedirect
from django.shortcuts import render_to_response, get_object_or_404
from django.template import Context, loader, RequestContext
from settings import MEDIA_ROOT

from django.views.decorators.cache import cache_control

import Image

@cache_control(no_cache=True)
def index(request):
    images = default_storage.listdir("raw")[1] 
    images_and_exts = []
    for image in images:
        images_and_exts.append([image, os.path.splitext(image)[1][1:]])
    return render_to_response('maus/index.html', {'images': images_and_exts})

def raw(request, image):
    image_path = os.path.join("raw", image)
    if not default_storage.exists(image_path): 
        raise Http404 # Page not found.
    image_file = default_storage.open(image_path)
    data = image_file.read()
    image_file.close()
    image_type = os.path.splitext(image)[1][1:] 
    return HttpResponse(data, mimetype="image/%s" % image_type)

def graph(request, image):
    image_path = os.path.join("raw", image)
    # Check image exists.
    if not default_storage.exists(image_path): 
        raise Http404 # Page not found.
    [image_name, image_type] = os.path.splitext(image)
    image_type = image_type[1:] 
    return render_to_response('maus/graph.html', 
        {'image_name': image_name, 'image_type': image_type})

def thumb(request, image):
    image_path = os.path.join("raw", image)
    # Check image exists.
    if not default_storage.exists(image_path): 
        raise Http404 # Page not found.
    [image_name, image_type] = os.path.splitext(image)
    # Get thumbnail name.
    thumb_name = image_name + "-thumb" + ".jpg"
    thumb_path = os.path.join("thumbs", thumb_name)
    abs_thumb_path = os.path.join(MEDIA_ROOT, thumb_path)
    if not default_storage.exists(thumb_path):
        # Create and save to cache.
        image_file = Image.open(os.path.join(MEDIA_ROOT, "raw", image))
        image_file.thumbnail((200,200), Image.ANTIALIAS)
        image_file.save(abs_thumb_path, "JPEG")
    else:
        # Reload cached image.
        image_file = Image.open(abs_thumb_path)
    # Create and save to cache.
    image_file = Image.open(os.path.join(MEDIA_ROOT, "raw", image))
    image_file.thumbnail((200,200), Image.ANTIALIAS)
    image_file.save(abs_thumb_path, "JPEG")

    response = HttpResponse(mimetype="image/jpg") 
    image_file.save(response, "JPEG") 
    return response 

def convert(image, image_type):
    image_path = os.path.join("raw", image)
    if not default_storage.exists(image_path): 
        raise Http404 # Page not found.
    image_file = Image.open(os.path.join(MEDIA_ROOT, "raw", image))
    response = HttpResponse(mimetype="image/" + image_type) 
    image_file.save(response, image_type) 
    return response 

def png(request, image):
    return convert(image, "png")

def eps(request, image):
    return convert(image, "eps")
